Slightly move letter tiles downwards

Change-Id: I6b62fa442a4c739acf6ed7a4eed37f346361c8f8
diff --git a/src/com/android/dialer/list/PhoneFavoriteTileView.java b/src/com/android/dialer/list/PhoneFavoriteTileView.java
index 5f2d2a9..208e350 100644
--- a/src/com/android/dialer/list/PhoneFavoriteTileView.java
+++ b/src/com/android/dialer/list/PhoneFavoriteTileView.java
@@ -43,9 +43,9 @@
     private static final boolean DEBUG = false;
 
     // These parameters instruct the photo manager to display the default image/letter at 70% of
     // its normal size, and vertically offset upwards 14% towards the top of the letter tile, to
     // make room for the contact name and number label at the bottom of the image.
-    private static final float DEFAULT_IMAGE_LETTER_OFFSET = -0.14f;
+    private static final float DEFAULT_IMAGE_LETTER_OFFSET = -0.12f;
     private static final float DEFAULT_IMAGE_LETTER_SCALE = 0.70f;
 
     /** View that contains the transparent shadow that is overlaid on top of the contact image. */
@@ -43,9 +43,9 @@
 
     // These parameters instruct the photo manager to display the default image/letter at 70% of
-    // its normal size, and vertically offset upwards 14% towards the top of the letter tile, to
+    // its normal size, and vertically offset upwards 12% towards the top of the letter tile, to
     // make room for the contact name and number label at the bottom of the image.